# -*- coding: utf-8 -*-

from django.test import TestCase
from django.test.client import RequestFactory

from cms.plugin_rendering import ContentRenderer

from ..models import ReferencePlugin as ReferencePluginModel


class ReferencePluginTest(TestCase):
    fixtures = [
        'reference_cmsplugin/tests/test_plugin.yaml',
    ]

    def test_plugin_context_empty_categories(self):
        model_instance = ReferencePluginModel.objects.get(pk=1)
        plugin_instance = model_instance.get_plugin_class_instance()
        context = plugin_instance.render({}, model_instance, None)
        assert context['instance'] == model_instance
        assert list(context['references'].values_list('id', flat=True)) == [1, 2, 3]

    def test_plugin_context_categories(self):
        model_instance = ReferencePluginModel.objects.get(pk=2)
        plugin_instance = model_instance.get_plugin_class_instance()
        context = plugin_instance.render({}, model_instance, None)
        assert context['instance'] == model_instance
        assert list(context['references'].values_list('id', flat=True)) == [1, 2]

    def test_plugin_html(self):
        model_instance = ReferencePluginModel.objects.get(pk=1)
        renderer = ContentRenderer(request=RequestFactory())
        html = renderer.render_plugin(model_instance, {})
        assert 'class="reference"' in html
